==> docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2/luna-sdk_alma_rel_v.5.31.2/doc/fsdk/html/search/enumvalues_f.js <==
var searchData=
[
  ['short',['Short',['../structfsdk_1_1_human_attribute_result.html#a5b39f39ce497f8870f4acfc5f032efeda30bb747c98bccdd11b3f89e644c4d0ad',1,'fsdk::HumanAttributeResult']]],
  ['signature',['Signature',['../structfsdk_1_1_i_serializable_object.html#a2e8ee7bbbbc97731f3dddfcf9c5276f0a8c09001c99ecb6fdd8d6023fcf039054',1,'fsdk::ISerializableObject']]],
  ['size',['Size',['../structfsdk_1_1_i_serializable_object.html#a2e8ee7bbbbc97731f3dddfcf9c5276f0a6f6cb72d544962fa333e2e34ce64f719',1,'fsdk::ISerializableObject']]],
  ['smilelips',['SmileLips',['../group___estimator_group.html#gga1021a188b3259b154cb0dd34dbf70aaaa2704ad942193c68aad9f4b1e941a54f7',1,'fsdk']]],
  ['smileopen',['SmileOpen',['../group___estimator_group.html#gga1021a188b3259b154cb0dd34dbf70aaaa8cbf1efa683b86f8290abeeeb9238390',1,'fsdk']]],
  ['solid',['Solid',['../group___estimator_group.html#gga138fe26fec23c695363e62a47a5df8e5ae41480b6bbfbf7407974a88d3d34f4fa',1,'fsdk']]],
  ['statedoesntallowfuturecreation',['StateDoesntAllowFutureCreation',['../namespacefsdk.html#a4d0fbacdb0e56a6f79c2eb3e276c4e83a8a986d01729ce1c0f7850a2a2a8d6adc',1,'fsdk']]],
  ['statenotcancelable',['StateNotCancelable',['../namespacefsdk.html#a4d0fbacdb0e56a6f79c2eb3e276c4e83a801f898435bf3dbee309450663b0e2b2',1,'fsdk']]],
  ['statenotfailable',['StateNotFailable',['../namespacefsdk.html#a4d0fbacdb0e56a6f79c2eb3e276c4e83acb325477696c2966ed1115474086076d',1,'fsdk']]],
  ['statenotfulfillable',['StateNotFulfillable',['../namespacefsdk.html#a4d0fbacdb0e56a6f79c2eb3e276c4e83ae3edadd584e4efcdca61a840abdf7c4b',1,'fsdk']]],
  ['string',['String',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947ac62a83138afcfe41b9c64a6e6026f5fb',1,'fsdk::ISettingsProvider::Value']]],
  ['stubble',['Stubble',['../group___estimator_group.html#ggac40caf1f72fab400cd2460f9ac2237c0a3a92fb363a71b7c51f9acac7ccb3f6d5',1,'fsdk']]],
  ['sunglasses',['SunGlasses',['../group___estimator_group.html#ggaa45cbedc4e8044e57d4b88144be36478ae6798db673b98a47d715e139a67e81ff',1,'fsdk']]],
  ['sv_5fdebug',['SV_DEBUG',['../_log_8h.html#a3221e435013d701a0b34a8fe5ba3d8ada0c7e2181976713a29d30a446507379cf',1,'fsdk::log']]],
  ['sv_5fdefault',['SV_DEFAULT',['../_log_8h.html#a3221e435013d701a0b34a8fe5ba3d8ada5cdd5ba02b03a41e94ddbe516ceac375',1,'fsdk::log']]],
  ['sv_5ferror',['SV_ERROR',['../_log_8h.html#a3221e435013d701a0b34a8fe5ba3d8adae8c889d368284706aaf4ff25f6ca10a5',1,'fsdk::log']]],
  ['sv_5finfo',['SV_INFO',['../_log_8h.html#a3221e435013d701a0b34a8fe5ba3d8ada8cc15ff64a6c56392ce57f74fd21ebd3',1,'fsdk::log']]],
  ['sv_5fwarn',['SV_WARN',['../_log_8h.html#a3221e435013d701a0b34a8fe5ba3d8ada7930eb19e00606b675d1134fdfae194e',1,'fsdk::log']]],
  ['sync',['Sync',['../namespacefsdk.html#a0f4cbbc8c61f0127bd75695e76869860ad8e87c0927539672f54462c837be0b7f',1,'fsdk']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0/luna-sdk_alma_rel_v.5.34.0/doc/fsdk/html/search/enumvalues_f.js <==
var searchData=
[
  ['short',['Short',['../structfsdk_1_1_human_attribute_result.html#a5b39f39ce497f8870f4acfc5f032efeda30bb747c98bccdd11b3f89e644c4d0ad',1,'fsdk::HumanAttributeResult']]],
  ['shoulderstraps',['ShoulderStraps',['../structfsdk_1_1_duty_uniform_estimation.html#aa7c09a87e1b87f6304ae709243cb1457a49dc251d1971bca219676e9f5b30579e',1,'fsdk::DutyUniformEstimation']]],
  ['signature',['Signature',['../structfsdk_1_1_i_serializable_object.html#a2e8ee7bbbbc97731f3dddfcf9c5276f0a8c09001c99ecb6fdd8d6023fcf039054',1,'fsdk::ISerializableObject']]],
  ['size',['Size',['../structfsdk_1_1_i_serializable_object.html#a2e8ee7bbbbc97731f3dddfcf9c5276f0a6f6cb72d544962fa333e2e34ce64f719',1,'fsdk::ISerializableObject']]],
  ['smilelips',['SmileLips',['../group___estimator_group.html#gga1021a188b3259b154cb0dd34dbf70aaaa2704ad942193c68aad9f4b1e941a54f7',1,'fsdk']]],
  ['smileopen',['SmileOpen',['../group___estimator_group.html#gga1021a188b3259b154cb0dd34dbf70aaaa8cbf1efa683b86f8290abeeeb9238390',1,'fsdk']]],
  ['solid',['Solid',['../group___estimator_group.html#gga138fe26fec23c695363e62a47a5df8e5ae41480b6bbfbf7407974a88d3d34f4fa',1,'fsdk']]],
  ['statedoesntallowfuturecreation',['StateDoesntAllowFutureCreation',['../namespacefsdk.html#a4d0fbacdb0e56a6f79c2eb3e276c4e83a8a986d01729ce1c0f7850a2a2a8d6adc',1,'fsdk']]],
  ['statenotcancelable',['StateNotCancelable',['../namespacefsdk.html#a4d0fbacdb0e56a6f79c2eb3e276c4e83a801f898435bf3dbee309450663b0e2b2',1,'fsdk']]],
  ['statenotfailable',['StateNotFailable',['../namespacefsdk.html#a4d0fbacdb0e56a6f79c2eb3e276c4e83acb325477696c2966ed1115474086076d',1,'fsdk']]],
  ['statenotfulfillable',['StateNotFulfillable',['../namespacefsdk.html#a4d0fbacdb0e56a6f79c2eb3e276c4e83ae3edadd584e4efcdca61a840abdf7c4b',1,'fsdk']]],
  ['string',['String',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947ac62a83138afcfe41b9c64a6e6026f5fb',1,'fsdk::ISettingsProvider::Value']]],
  ['stubble',['Stubble',['../group___estimator_group.html#ggac40caf1f72fab400cd2460f9ac2237c0a3a92fb363a71b7c51f9acac7ccb3f6d5',1,'fsdk']]],
  ['sunglasses',['SunGlasses',['../group___estimator_group.html#ggaa45cbedc4e8044e57d4b88144be36478ae6798db673b98a47d715e139a67e81ff',1,'fsdk']]],
  ['sv_5fdebug',['SV_DEBUG',['../_log_8h.html#a3221e435013d701a0b34a8fe5ba3d8ada0c7e2181976713a29d30a446507379cf',1,'fsdk::log']]],
  ['sv_5fdefault',['SV_DEFAULT',['../_log_8h.html#a3221e435013d701a0b34a8fe5ba3d8ada5cdd5ba02b03a41e94ddbe516ceac375',1,'fsdk::log']]],
  ['sv_5ferror',['SV_ERROR',['../_log_8h.html#a3221e435013d701a0b34a8fe5ba3d8adae8c889d368284706aaf4ff25f6ca10a5',1,'fsdk::log']]],
  ['sv_5finfo',['SV_INFO',['../_log_8h.html#a3221e435013d701a0b34a8fe5ba3d8ada8cc15ff64a6c56392ce57f74fd21ebd3',1,'fsdk::log']]],
  ['sv_5fwarn',['SV_WARN',['../_log_8h.html#a3221e435013d701a0b34a8fe5ba3d8ada7930eb19e00606b675d1134fdfae194e',1,'fsdk::log']]],
  ['sync',['Sync',['../namespacefsdk.html#a0f4cbbc8c61f0127bd75695e76869860ad8e87c0927539672f54462c837be0b7f',1,'fsdk']]]
];
